==> unixODBC-1.8.tar.gz: unixODBC-1.8/cur/SQLAllocHandle.c <==
/*********************************************************************
 *
 * unixODBC Cursor Library
 *
 * Created by Nick Gorham
 * (nick@easysoft.com).
 *
 * copyright (c) 1999 Nick Gorham
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **********************************************************************
 *
 * $Id: SQLAllocHandle.c,v 1.1 1999/09/19 22:22:50 ngorham Exp $
 *
 * $Log: SQLAllocHandle.c,v $
 * Revision 1.1  1999/09/19 22:22:50  ngorham
 *
 *
 * Added first cursor library work, read only at the moment and only works
 * with selects with no where clause
 *
 *
 **********************************************************************/

#include "cursorlibrary.h"

SQLRETURN CLAllocHandle( SQLSMALLINT handle_type,
           SQLHANDLE input_handle,
           SQLHANDLE *output_handle,
           SQLHANDLE dm_handle )
{
    switch ( handle_type )
    {
        case SQL_HANDLE_ENV:
        case SQL_HANDLE_DBC:
          /* 
           * shouldn't be here
           */

          return SQL_ERROR;
          break;

        case SQL_HANDLE_STMT:
          {
            CLHDBC cl_connection = (CLHDBC) input_handle;
            CLHSTMT cl_statement;
            DMHDBC connection = cl_connection -> dm_connection;
            SQLCHAR s0[ 20 ];
            SQLRETURN ret;

            /*
             * allocate a cursor lib statement
             */

            cl_statement = malloc( sizeof( *cl_statement ));

            if ( !cl_statement )
            {
                logPushMsg( connection -> log_handle,
                        __get_pid( s0 ),
                        "CL " __FILE__,
                        __LINE__,
                        LOG_INFO,
                        LOG_INFO,
                        "Error: IM001" );

                __post_internal_error( &connection -> error,
                        ERROR_HY001, NULL,
                        connection -> environment -> requested_version );

                return SQL_ERROR;
            }

            memset( cl_statement, 0, sizeof( *cl_statement ));
            cl_statement -> cl_connection = cl_connection;
            cl_statement -> dm_statement = ( DMHSTMT ) dm_handle; 

            ret = SQLALLOCHANDLE( cl_connection, 
                    handle_type,
                    cl_connection -> driver_dbc,
                    &cl_statement -> driver_stmt,
                    NULL );

            if ( SQL_SUCCEEDED( ret ))
            {
                *output_handle = ( SQLHSTMT ) cl_statement;
            }
            else
            {
                free( cl_statement );
            }
            return ret;
          }
          break;

        case SQL_HANDLE_DESC:
          {
            CLHDBC cl_connection = (CLHDBC) input_handle;

            return SQLALLOCHANDLE( cl_connection,
                  handle_type,
                  input_handle,
                  output_handle,
                  NULL );
           }
           break;
    }
}

==> unixODBC-1.8.1.tar.gz: unixODBC-1.8.1/cur/SQLAllocHandle.c <==
/*********************************************************************
 *
 * unixODBC Cursor Library
 *
 * Created by Nick Gorham
 * (nick@easysoft.com).
 *
 * copyright (c) 1999 Nick Gorham
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **********************************************************************
 *
 * $Id: SQLAllocHandle.c,v 1.1 1999/09/19 22:22:50 ngorham Exp $
 *
 * $Log: SQLAllocHandle.c,v $
 * Revision 1.1  1999/09/19 22:22:50  ngorham
 *
 *
 * Added first cursor library work, read only at the moment and only works
 * with selects with no where clause
 *
 *
 **********************************************************************/

#include "cursorlibrary.h"

SQLRETURN CLAllocHandle( SQLSMALLINT handle_type,
           SQLHANDLE input_handle,
           SQLHANDLE *output_handle,
           SQLHANDLE dm_handle )
{
    switch ( handle_type )
    {
        case SQL_HANDLE_ENV:
        case SQL_HANDLE_DBC:
          /* 
           * shouldn't be here
           */

          return SQL_ERROR;
          break;

        case SQL_HANDLE_STMT:
          {
            CLHDBC cl_connection = (CLHDBC) input_handle;
            CLHSTMT cl_statement;
            DMHDBC connection = cl_connection -> dm_connection;
            SQLCHAR s0[ 20 ];
            SQLRETURN ret;

            /*
             * allocate a cursor lib statement
             */

            cl_statement = malloc( sizeof( *cl_statement ));

            if ( !cl_statement )
            {
                dm_log_write( connection -> log_handle,
                        __get_pid( s0 ),
                        "CL " __FILE__,
                        __LINE__,
                        LOG_INFO,
                        LOG_INFO,
                        "Error: IM001" );

                __post_internal_error( &connection -> error,
                        ERROR_HY001, NULL,
                        connection -> environment -> requested_version );

                return SQL_ERROR;
            }

            memset( cl_statement, 0, sizeof( *cl_statement ));
            cl_statement -> cl_connection = cl_connection;
            cl_statement -> dm_statement = ( DMHSTMT ) dm_handle; 

            ret = SQLALLOCHANDLE( cl_connection, 
                    handle_type,
                    cl_connection -> driver_dbc,
                    &cl_statement -> driver_stmt,
                    NULL );

            if ( SQL_SUCCEEDED( ret ))
            {
                *output_handle = ( SQLHSTMT ) cl_statement;
            }
            else
            {
                free( cl_statement );
            }
            return ret;
          }
          break;

        case SQL_HANDLE_DESC:
          {
            CLHDBC cl_connection = (CLHDBC) input_handle;

            return SQLALLOCHANDLE( cl_connection,
                  handle_type,
                  input_handle,
                  output_handle,
                  NULL );
           }
           break;
    }
}
